@@ -18,28 +18,25 @@ import abc
 import six
 
 from neutron.api import extensions
-from neutron.api.v2 import attributes as attr
 from neutron.api.v2 import base
 from neutron.api.v2 import resource_helper
-from neutron.common import exceptions as n_exc
 from neutron import manager
 from neutron.plugins.common import constants as n_const
 from neutron.services.service_base import ServicePluginBase
 
+from neutron_lib import api
+from neutron_lib import exceptions as n_exc
+
 from oslo_log import log
 
+from networking_bgpvpn._i18n import _
+
 from networking_bgpvpn.neutron import extensions as bgpvpn_ext
 from networking_bgpvpn.neutron.services.common import constants
 
 LOG = log.getLogger(__name__)
 
 
-# Regular expression to validate Route Target list format
-# ["<asn1>:<nn1>","<asn2>:<nn2>", ...] with asn and nn in range 0-65535
-RT_REGEX = (r'^((?:0|[1-9]\d{0,3}|[1-5]\d{4}|6[0-4]\d{3}|65[0-4]\d{2}|655[0-2]'
-            r'\d|6553[0-5]):(?:0|[1-9]\d{0,3}|[1-5]\d{4}|6[0-4]\d{3}|65[0-4]\d'
-            r'{2}|655[0-2]\d|6553[0-5]))$')
-
 extensions.append_api_extensions_path(bgpvpn_ext.__path__)
 n_const.EXT_TO_SERVICE_MAPPING['bgpvpn'] = constants.BGPVPN
 
@@ -67,6 +64,11 @@ class BGPVPNRDNotSupported(n_exc.BadRequest):
                 "route distinguisher")
 
 
+class BGPVPNFindFromNetNotSupported(n_exc.BadRequest):
+    message = _("BGPVPN %(driver)s driver does not support to fetch BGPVPNs "
+                "associated to network id %(net_id)")
+
+
 class BGPVPNNetAssocAlreadyExists(n_exc.BadRequest):
     message = _("network %(net_id)s is already associated to "
                 "BGPVPN %(bgpvpn_id)s")
@@ -107,7 +109,7 @@ def _validate_rt_list(data, valid_values=None):
         return msg
 
     for item in data:
-        msg = attr._validate_regex(item, RT_REGEX)
+        msg = api.validators.validate_regex(item, constants.RT_REGEX)
         if msg:
             LOG.debug(msg)
             return msg
@@ -117,8 +119,7 @@ def _validate_rt_list(data, valid_values=None):
         LOG.debug(msg)
         return msg
 
-validators = {'type:route_target_list': _validate_rt_list}
-attr.validators.update(validators)
+api.validators.add_validator('type:route_target_list', _validate_rt_list)
 
 RESOURCE_ATTRIBUTE_MAP = {
     constants.BGPVPN_RES: {
@@ -144,25 +145,25 @@ RESOURCE_ATTRIBUTE_MAP = {
                  'enforce_policy': True},
         'route_targets': {'allow_post': True, 'allow_put': True,
                           'default': [],
-                          'convert_to': attr.convert_to_list,
+                          'convert_to': api.converters.convert_to_list,
                           'validate': {'type:route_target_list': None},
                           'is_visible': True,
                           'enforce_policy': True},
         'import_targets': {'allow_post': True, 'allow_put': True,
                            'default': [],
-                           'convert_to': attr.convert_to_list,
+                           'convert_to': api.converters.convert_to_list,
                            'validate': {'type:route_target_list': None},
                            'is_visible': True,
                            'enforce_policy': True},
         'export_targets': {'allow_post': True, 'allow_put': True,
                            'default': [],
-                           'convert_to': attr.convert_to_list,
+                           'convert_to': api.converters.convert_to_list,
                            'validate': {'type:route_target_list': None},
                            'is_visible': True,
                            'enforce_policy': True},
         'route_distinguishers': {'allow_post': True, 'allow_put': True,
                                  'default': [],
-                                 'convert_to': attr.convert_to_list,
+                                 'convert_to': api.converters.convert_to_list,
                                  'validate': {'type:route_target_list': None},
                                  'is_visible': True,
                                  'enforce_policy': True},
@@ -239,13 +240,6 @@ class Bgpvpn(extensions.ExtensionDescriptor):
     def get_resources(cls):
         plural_mappings = resource_helper.build_plural_mappings(
             {}, RESOURCE_ATTRIBUTE_MAP)
-        plural_mappings['route_targets'] = 'route_target'
-        plural_mappings['import_targets'] = 'import_target'
-        plural_mappings['export_targets'] = 'export_target'
-        plural_mappings['route_distinguishers'] = 'route_distinguishers'
-        plural_mappings['network_associations'] = 'network_association'
-        plural_mappings['router_associations'] = 'router_association'
-        attr.PLURALS.update(plural_mappings)
         resources = resource_helper.build_resource_info(plural_mappings,
                                                         RESOURCE_ATTRIBUTE_MAP,
                                                         constants.BGPVPN,
