@@ -20,8 +20,6 @@ OpenVSwitch agent
 
 import types
 
-import logging
-
 from networking_bagpipe.agent import bagpipe_bgp_agent
 
 from neutron_lib import constants as n_const
@@ -37,8 +35,6 @@ from neutron.plugins.ml2.drivers.openvswitch.agent.openflow.ovs_ofctl \
 from neutron.plugins.ml2.drivers.openvswitch.agent import \
     ovs_agent_extension_api
 
-LOG = logging.getLogger(__name__)
-
 
 class OVSBridgeIntercept(ofctl_br_tun.OVSTunnelBridge,
                          native_br_tun.OVSTunnelBridge):
