@@ -19,8 +19,9 @@ import uuid
 from oslo_log import log
 from oslo_utils import uuidutils
 
-from neutron.common import exceptions as n_exc
-from neutron.i18n import _LI
+from neutron_lib import exceptions as n_exc
+
+from networking_bgpvpn._i18n import _LI
 
 from networking_bgpvpn.neutron.extensions import bgpvpn as bgpvpn_ext
 from networking_bgpvpn.neutron.services.common import constants
@@ -405,6 +406,12 @@ class OpenContrailBGPVPNDriver(driver_api.BGPVPNDriverBase):
 
         return net_assoc
 
+    def find_bgpvpns_for_network(self, context, network_id, bgpvpn_type=None):
+        # TODO(matrohon) : get bgpvpns from the kv store
+        raise bgpvpn_ext.BGPVPNFindFromNetNotSupported(
+            driver=OPENCONTRAIL_BGPVPN_DRIVER_NAME,
+            net_id=network_id)
+
     def create_router_assoc(self, context, bgpvpn_id, router_association):
         raise bgpvpn_ext.BGPVPNRouterAssociationNotSupported(
             driver=OPENCONTRAIL_BGPVPN_DRIVER_NAME)
@@ -420,3 +427,7 @@ class OpenContrailBGPVPNDriver(driver_api.BGPVPNDriverBase):
     def delete_router_assoc(self, context, assoc_id, bgpvpn_id):
         raise bgpvpn_ext.BGPVPNRouterAssociationNotSupported(
             driver=OPENCONTRAIL_BGPVPN_DRIVER_NAME)
+
+    def find_bgpvpns_for_router(self, context, router_id):
+        raise bgpvpn_ext.BGPVPNRouterAssociationNotSupported(
+            driver=OPENCONTRAIL_BGPVPN_DRIVER_NAME)
